@@ -353,10 +353,10 @@ class Device(SubDir):
 
         self._unseen = 0
         self._events = []
-        self._wait_bus = anyio.create_event()
+        self._wait_bus = anyio.Event()
         self._poll = {}  # name > poll task scopes
         self._intervals = {}
-        self._task_lock = anyio.create_lock()
+        self._task_lock = anyio.Lock()
 
         return self
 
@@ -418,7 +418,7 @@ class Device(SubDir):
         if self.bus is bus:
             return
         self.bus = bus
-        await self._wait_bus.set()
+        self._wait_bus.set()
         await self.service.push_event(DeviceLocated(self))
         for typ, val in self._intervals.items():
             await self._set_poll_task(typ, val)
@@ -429,7 +429,7 @@ class Device(SubDir):
     async def delocate(self, bus):
         """The device is no longer located here."""
         if self.bus is bus:
-            self._wait_bus = anyio.create_event()
+            self._wait_bus = anyio.Event()
             await self._delocate()
 
     async def _delocate(self):
@@ -619,9 +619,13 @@ class TemperatureDevice(Device):
         yield "temperature"
         yield "alarm"
 
-    async def poll_temperature(self):
-        # t = await self.latesttemp
-        t = await self.temperature
+    async def poll_temperature(self, simul=False):
+        # Bug workaround
+        t = await (self.latesttemp if simul and len(self.bus.path)<=1 else self.temperature)
+        if t == 85:
+            logger.error("TEMP: got 85 on %r", self)
+            return
+
         await self.service.push_event(DeviceValue(self, "temperature", t))
 
 
@@ -676,7 +680,7 @@ class VoltageDevice(Device):
         yield "voltage"
         yield "alarm"
 
-    async def poll_voltage(self):
+    async def poll_voltage(self, simul=False):
         v = await self.volt_all
         await self.service.push_event(DeviceValue(self, "volt_all", v))
 
